# Craft Providers

This project aims to provide python interfaces for instantiating and executing
builds for a variety of target environments.

Initial providers include:
- LXD containers
- Multipass VMs

Host support is targeted for:
- Linux
- Mac OS X
- Windows

# License

Free software: GNU Lesser General Public License v3

# Documentation:

https://craft-providers.readthedocs.io.
